@@ -80,11 +80,16 @@ casper.eachThen(optsList, function(response) {
   // Go to url and perform the desired screenshot
   this.zoom(opts.zoom)
     .viewport(opts.zoom * opts.vwidth, opts.zoom * opts.vheight)
-    .thenOpen(opts.url, function() {
-      this.wait(opts.delay * 1000, function() {
-        var cr = findClipRect(opts, this);
-        this.capture(opts.file, cr);
-      });
+    .thenOpen(opts.url)
+    .wait(opts.delay * 1000)
+    .then(function() {
+      if (opts.eval) {
+        eval(opts.eval);
+      }
+    })
+    .then(function() {
+      var cr = findClipRect(opts, this);
+      this.capture(opts.file, cr);
     });
 });
 
